@@ -93,6 +93,7 @@ __all__ = stbt_core.__all__ + [
     "measure_av_sync",
     "play_audio_file",
     "prometheus",
+    "RmsVolumeResult",
     "Roku",
     "segment",
     "stop_job",
@@ -208,7 +209,7 @@ def audio_chunks(time_index=None, _dut=None):
     return iter([AudioChunk((4800,), dtype=numpy.float32)])
 
 
-def get_rms_volume(duration_secs=3, stream=None):
+def get_rms_volume(duration_secs=3, stream=None) -> "RmsVolumeResult":
     """Calculate the average `RMS`_ volume of the audio over the given duration.
 
     For example, to check that your mute button works::
@@ -228,27 +229,47 @@ def get_rms_volume(duration_secs=3, stream=None):
     :raises ZeroDivisionError: If ``duration_secs`` is shorter than one sample
         or ``stream`` contains no samples.
 
-    :returns:
-        An object with the following attributes:
-
-        * **amplitude** (*float*) – The RMS amplitude over the specified
-          window. This is a value between 0.0 (absolute silence) and 1.0 (a
-          full-range square wave).
-
-        * **time** (*float*) – The start of the window, as number of seconds
-          since the unix epoch (1970-01-01T00:00Z). This is compatible with
-          ``time.time()`` and ``stbt.Frame.time``.
-
-        * **duration_secs** (*float*) – The window size, in seconds. Typically
-          this will be the same as passed into ``get_rms_volume()``.
+    :rtype: RmsVolumeResult
 
     .. _RMS: https://en.wikipedia.org/wiki/Root_mean_square
     """
     _raise_premium("get_rms_volume")
-    return _RmsVolumeResult(0.0, 0.0, 0.0)
+    return RmsVolumeResult(0.0, 0.0, 0.0)
 
 
-_RmsVolumeResult = namedtuple('RmsVolumeResult', 'time duration_secs amplitude')
+class RmsVolumeResult(
+        namedtuple('RmsVolumeResult', 'time duration_secs amplitude')):
+    """The result from `get_rms_volume`.
+
+    :ivar float amplitude: The `RMS`_ amplitude over the specified window. This
+      is a value between 0.0 (absolute silence) and 1.0 (a full-range square
+      wave).
+
+    :ivar float time: The start of the window, as number of seconds since the
+      unix epoch (1970-01-01T00:00Z). This is compatible with ``time.time()``
+      and ``stbt.Frame.time``.
+
+    :ivar int|float duration_secs: The window size in seconds, as given to
+      `get_rms_volume`.
+    """
+
+    def dBov(self, noise_floor_amplitude=0.0003) -> float:
+        """The RMS amplitude converted to `dBov`_.
+
+        Decibels are a logarithmic measurement; human perception of loudness is
+        also logarithmic, so decibels are a useful way to measure loudness.
+
+        This is a value between -70 (silence, or near silence) and 0 (the
+        loudest possible signal, a full-scale square wave).
+
+        :param noise_floor_amplitude: This is used to avoid `ZeroDivisionError`
+            exceptions. We consider 0 amplitude to be this non-zero value
+            instead. It defaults to ~0.0003 (-70dBov).
+
+        .. _dBov: https://en.wikipedia.org/wiki/DBFS
+        """
+        import math
+        return 20 * math.log10(max(self.amplitude, noise_floor_amplitude))
 
 
 class VolumeChangeDirection(IntEnum):
@@ -267,7 +288,8 @@ class VolumeChangeTimeout(AssertionError):
 
 def wait_for_volume_change(
         direction=VolumeChangeDirection.LOUDER, stream=None,
-        window_size_secs=0., threshold_db=0., noise_floor=0.0, timeout_secs=0.):
+        window_size_secs=0.400, threshold_db=10.,
+        noise_floor_amplitude=0.0003, timeout_secs=10):
 
     """Wait for changes in the RMS audio volume.
 
@@ -329,9 +351,9 @@ def wait_for_volume_change(
     :param noise_floor_amplitude: This is used to avoid `ZeroDivisionError`
         exceptions.  The change from an amplitude of 0 to 0.1 is ∞ dB.
         This isn't very practical to deal with so we consider 0 amplitude to be
-        this non-zero ``noise_floor_amplitude`` instead. It defaults to ~0.0003
-        (-70dBov). Increase this value if there is some sort of background
-        noise that you want to ignore.
+        this non-zero value instead. It defaults to ~0.0003 (-70dBov). Increase
+        this value if there is some sort of background noise that you want to
+        ignore.
 
     :type timeout_secs: float
     :param timeout_secs: Timeout in seconds. If no significant volume change is
@@ -347,10 +369,10 @@ def wait_for_volume_change(
         * **direction** (`VolumeChangeDirection`) – This will be either
           ``VolumeChangeDirection.LOUDER`` or ``VolumeChangeDirection.QUIETER``
           as given to ``wait_for_volume_change``.
-        * **rms_before** (see `get_rms_volume`) – The RMS volume averaged over
+        * **rms_before** (`RmsVolumeResult`) – The RMS volume averaged over
           the window immediately before the volume change. Use
           ``result.rms_before.amplitude`` to get the RMS amplitude as a float.
-        * **rms_after** (see `get_rms_volume`) – The RMS volume averaged over
+        * **rms_after** (`RmsVolumeResult`) – The RMS volume averaged over
           the window immediately after the volume change.
         * **difference_db** (*float*) – Ratio between ``rms_after`` and
           ``rms_before``, in decibels.
@@ -366,8 +388,8 @@ def wait_for_volume_change(
     """
     _raise_premium("wait_for_volume_change")
     return _VolumeChangeResult(VolumeChangeDirection.LOUDER,
-                               _RmsVolumeResult(0.0, 0.0, 0.0),
-                               _RmsVolumeResult(0.0, 0.0, 0.0),
+                               RmsVolumeResult(0.0, 0.0, 0.0),
+                               RmsVolumeResult(0.0, 0.0, 0.0),
                                0.0, 0.0, 0.0, 0.)
 
 
@@ -821,7 +843,7 @@ class Roku:
         _raise_premium("Roku")
         yield
 
-    def query_apps(self) -> dict[str, str]:
+    def query_apps(self) -> Dict[str, str]:
         """Returns a dict of ``application_id: name`` with all the apps
         installed on the Roku device.
         """
